@@ -37,12 +37,12 @@ from .exceptions import MojangError
 log = logging.getLogger(__name__)
 
 
+_API_BASE_URL = "https://api.mojang.com"
+_SESSIONSERVER_BASE_URL = "https://sessionserver.mojang.com"
+_AUTHSERVER_BASE_URL = "https://authserver.mojang.com"
+
+
 class API(HTTPClient):
-
-    _API_BASE_URL = "https://api.mojang.com"
-    _SESSIONSERVER_BASE_URL = "https://sessionserver.mojang.com"
-    _AUTHSERVER_BASE_URL = "https://authserver.mojang.com"
-
     def __init__(
         self,
         session: Optional[requests.Session] = None,
@@ -85,11 +85,11 @@ class API(HTTPClient):
         """
 
         if timestamp:
-            url = f"{self._API_BASE_URLf}/users/profiles/minecraft/{username}?at={timestamp}"
+            url = f"{_API_BASE_URL}/users/profiles/minecraft/{username}?at={timestamp}"
         else:
-            url = f"{self._API_BASE_URL}/users/profiles/minecraft/{username}"
+            url = f"{_API_BASE_URL}/users/profiles/minecraft/{username}"
 
-        resp = self.session.get(url)
+        resp = self._get(url)
 
         if resp.status_code == 400:
             return None
@@ -128,9 +128,7 @@ class API(HTTPClient):
         if len(names) > 10:
             names = names[:10]
 
-        data = self.session.post(
-            f"{self._API_BASE_URL}/profiles/minecraft", json=names
-        ).json()
+        data = self._post(f"{_API_BASE_URL}/profiles/minecraft", json=names).json()
 
         if not isinstance(data, list):
             if data.get("error"):
@@ -157,9 +155,7 @@ class API(HTTPClient):
                 print("UUID does not appear to be valid.")
             ```
         """
-        resp = self.session.get(
-            f"{self._SESSIONSERVER_BASE_URL}/session/minecraft/profile/{uuid}"
-        )
+        resp = self._get(f"{_SESSIONSERVER_BASE_URL}/session/minecraft/profile/{uuid}")
 
         if resp.status_code == 400:
             return None
@@ -191,9 +187,7 @@ class API(HTTPClient):
                 # is_legacy_profile, and timestamp
             ```
         """
-        resp = self.session.get(
-            f"{self._SESSIONSERVER_BASE_URL}/session/minecraft/profile/{uuid}"
-        )
+        resp = self._get(f"{_SESSIONSERVER_BASE_URL}/session/minecraft/profile/{uuid}")
 
         try:
             value = resp.json()["properties"][0]["value"]
@@ -217,7 +211,7 @@ class API(HTTPClient):
                 print(hash)
             ```
         """
-        resp = self.session.get(f"{self._SESSIONSERVER_BASE_URL}/blockedservers")
+        resp = self._get(f"{_SESSIONSERVER_BASE_URL}/blockedservers")
         return resp.text.splitlines()
 
     def refresh_access_token(
@@ -259,9 +253,7 @@ class API(HTTPClient):
         }
 
         account = {}
-        data = self.session.post(
-            f"{self._AUTHSERVER_BASE_URL}/refresh", json=payload
-        ).json()
+        data = self._post(f"{_AUTHSERVER_BASE_URL}/refresh", json=payload).json()
 
         account["username"] = data["user"]["username"]
         account["uuid"] = data["user"]["id"]
