@@ -168,7 +168,7 @@ class MojangAuth(HTTPClient):
 
         return xbl_token, user_hash
 
-    def _get_xsts_token(self, xbl_token):
+    def _get_xsts_token(self, xbl_token: str):
         """Gets the XSTS token which is required to authenticate with Minecraft services"""
         json_data = {
             "Properties": {"SandboxId": "RETAIL", "UserTokens": [xbl_token]},
@@ -189,7 +189,7 @@ class MojangAuth(HTTPClient):
 
         return resp.json()["Token"]
 
-    def _authenticate_with_minecraft(self, user_hash, xsts_token):
+    def _authenticate_with_minecraft(self, user_hash: str, xsts_token: str):
         json_payload = {
             "identityToken": f"XBL3.0 x={user_hash};{xsts_token}",
             "ensureLegacyEnabled": True,
@@ -429,7 +429,8 @@ class Client(MojangAuth):
 
         if variant != "slim" and variant != "classic":
             raise ValueError("Skin variant must be set to either slim or classic.")
-        elif not image_path and not url:
+
+        if not image_path and not url:
             raise TypeError(
                 "Missing required parameters. Please supply a skin URL or a skin image path."
             )
